==> haskell-aeson-pretty-0.8.5-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.5
id: aeson-pretty-0.8.5-2EO0EMqzXO15I5RbkoIj7G
key: aeson-pretty-0.8.5-2EO0EMqzXO15I5RbkoIj7G
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: 3b244d7b19aa4271b1b200045d5864bd
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/aeson-pretty-0.8.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/aeson-pretty-0.8.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/aeson-pretty-0.8.5
hs-libraries: HSaeson-pretty-0.8.5-2EO0EMqzXO15I5RbkoIj7G
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 bytestring-0.10.8.1
    scientific-0.3.4.15-Is44CvKqXBF5ugVqyS94hI
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.5-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.5
id: aeson-pretty-0.8.5-7vGKngUCSMyDD0aWLX1AVR
key: aeson-pretty-0.8.5-7vGKngUCSMyDD0aWLX1AVR
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: 816e9938e1adf0d3585f115bc2ee05e2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/aeson-pretty-0.8.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/aeson-pretty-0.8.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/aeson-pretty-0.8.5
hs-libraries: HSaeson-pretty-0.8.5-7vGKngUCSMyDD0aWLX1AVR
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9 base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22 bytestring-0.10.8.1
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
